@@ -284,6 +284,7 @@ class DrdsInstance(
         "is_auto_renew": "isAutoRenew",
         "my_sql_version": "mySqlVersion",
         "pricing_cycle": "pricingCycle",
+        "resource_group_id": "resourceGroupId",
         "tags": "tags",
         "vpc_id": "vpcId",
         "vswitch_id": "vswitchId",
@@ -304,6 +305,7 @@ class DrdsInstanceProps:
         is_auto_renew: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]] = None,
         my_sql_version: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
         pricing_cycle: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+        resource_group_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
         tags: typing.Optional[typing.Sequence["RosDrdsInstance.TagsProperty"]] = None,
         vpc_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
         vswitch_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
@@ -321,6 +323,7 @@ class DrdsInstanceProps:
         :param is_auto_renew: Property isAutoRenew: Whether to renew the fee automatically, if it is purchased on a monthly basis, it will automatically renew for one month, and if it is purchased on an annual basis, it will automatically renew for one year. The parameter takes effect when the payment type is drdsPre.
         :param my_sql_version: Property mySqlVersion: The MySQL protocol version supported by DRDS. Valid values: 5 and 8. Default value: 5. This parameter is valid only when the primary instance is created. The read-only instance is the same as the primary instance by default.
         :param pricing_cycle: Property pricingCycle: The unit of the order period, year: year, month: month. The parameter takes effect when the payment type is drdsPre.
+        :param resource_group_id: Property resourceGroupId: Resource group id.
         :param tags: Property tags: Tags to attach to instance. Max support 20 tags to add during create instance. Each tag with two properties Key and Value, and Key is required.
         :param vpc_id: Property vpcId: Virtual private network ID, must be specified when creating a DRDS for VPC network type.
         :param vswitch_id: Property vswitchId: Virtual switch ID, must be specified when creating a DRDS for VPC network type.
@@ -342,6 +345,8 @@ class DrdsInstanceProps:
             self._values["my_sql_version"] = my_sql_version
         if pricing_cycle is not None:
             self._values["pricing_cycle"] = pricing_cycle
+        if resource_group_id is not None:
+            self._values["resource_group_id"] = resource_group_id
         if tags is not None:
             self._values["tags"] = tags
         if vpc_id is not None:
@@ -442,6 +447,14 @@ class DrdsInstanceProps:
         result = self._values.get("pricing_cycle")
         return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
 
+    @builtins.property
+    def resource_group_id(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]]:
+        '''Property resourceGroupId: Resource group id.'''
+        result = self._values.get("resource_group_id")
+        return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
+
     @builtins.property
     def tags(self) -> typing.Optional[typing.List["RosDrdsInstance.TagsProperty"]]:
         '''Property tags: Tags to attach to instance.
@@ -1207,6 +1220,23 @@ class RosDrdsInstance(
     ) -> None:
         jsii.set(self, "pricingCycle", value)
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="resourceGroupId")
+    def resource_group_id(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]]:
+        '''
+        :Property: resourceGroupId: Resource group id.
+        '''
+        return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], jsii.get(self, "resourceGroupId"))
+
+    @resource_group_id.setter
+    def resource_group_id(
+        self,
+        value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+    ) -> None:
+        jsii.set(self, "resourceGroupId", value)
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="tags")
     def tags(self) -> typing.Optional[typing.List["RosDrdsInstance.TagsProperty"]]:
@@ -1324,6 +1354,7 @@ class RosDrdsInstance(
         "is_auto_renew": "isAutoRenew",
         "my_sql_version": "mySqlVersion",
         "pricing_cycle": "pricingCycle",
+        "resource_group_id": "resourceGroupId",
         "tags": "tags",
         "vpc_id": "vpcId",
         "vswitch_id": "vswitchId",
@@ -1344,6 +1375,7 @@ class RosDrdsInstanceProps:
         is_auto_renew: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]] = None,
         my_sql_version: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
         pricing_cycle: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+        resource_group_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
         tags: typing.Optional[typing.Sequence[RosDrdsInstance.TagsProperty]] = None,
         vpc_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
         vswitch_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
@@ -1361,6 +1393,7 @@ class RosDrdsInstanceProps:
         :param is_auto_renew: 
         :param my_sql_version: 
         :param pricing_cycle: 
+        :param resource_group_id: 
         :param tags: 
         :param vpc_id: 
         :param vswitch_id: 
@@ -1382,6 +1415,8 @@ class RosDrdsInstanceProps:
             self._values["my_sql_version"] = my_sql_version
         if pricing_cycle is not None:
             self._values["pricing_cycle"] = pricing_cycle
+        if resource_group_id is not None:
+            self._values["resource_group_id"] = resource_group_id
         if tags is not None:
             self._values["tags"] = tags
         if vpc_id is not None:
@@ -1492,6 +1527,16 @@ class RosDrdsInstanceProps:
         result = self._values.get("pricing_cycle")
         return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
 
+    @builtins.property
+    def resource_group_id(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]]:
+        '''
+        :Property: resourceGroupId: Resource group id.
+        '''
+        result = self._values.get("resource_group_id")
+        return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
+
     @builtins.property
     def tags(self) -> typing.Optional[typing.List[RosDrdsInstance.TagsProperty]]:
         '''
